@@ -50,6 +50,24 @@ val get_hide_reserved : unit -> bool
 val set_hide_reserved : bool -> unit
   (** Modifies {!hide_reserved}. *)
 
+val create_implicits : bool signal
+  (** If [true] (not the default) expressions entered in the toplevel are
+      automatically bound, for example:
+
+      {[
+        # 3 + 4;;
+        _0 : int = 7
+        # _0 + 10;;
+        _1 : int = 17
+      ]}
+  *)
+
+val get_create_implicits : unit -> bool
+  (** Returns the value of {!create_implicits}. *)
+
+val set_create_implicits : bool -> unit
+  (** Modifies {!create_implicits}. *)
+
 val topfind_verbose : bool signal
   (** If [false] (the default) messages from findlib are hidden. This is only effective
       with findlib >= 1.4. *)
@@ -73,33 +91,15 @@ val get_show_box : unit -> bool
 val set_show_box : bool -> unit
   (** Modifies {!show_box}. *)
 
-(** Syntax. *)
-type syntax =
-  | Normal
-      (** No camlp4. *)
-  | Camlp4o
-      (** Camlp4, original syntax. *)
-  | Camlp4r
-      (** Camlp4, revised syntax. *)
+val set_margin_function : (LTerm_geom.size -> int option) -> unit
+  (** Margin of the standard and error formatters as a function of the screen size.
 
-val syntax : syntax signal
-  (** The syntax in use. If it is {!Camlp4o} or {!Camlp4r} quotations
-      are recognized. It is modified when you type [#camlp4o] or
-      [#camlp4r]. At the beginning it is {!Normal}. *)
+      The default is:
 
-val get_syntax : unit -> syntax
-  (** Returns the current value of {!syntax}. *)
-
-val set_syntax : syntax -> unit
-  (** Changes the syntax used in utop. If the syntax is the same as
-      the current one, it does nothing. Otherwise it loads camlp4 and
-      setup several configuration variables.
-
-      Notes:
-      - the syntax can only be changed once. Once you set it to
-        {!Camlp4o} or {!Camlp4r} you cannot change it again.
-      - Typing [#camlp4o] is the same as calling [set_syntax Camlp4o].
-      - Typing [#camlp4r] is the same as calling [set_syntax Camlp4r]. *)
+      {[
+        fun size -> Some (min 80 size.cols)
+      ]}
+  *)
 
 val phrase_terminator : string signal
   (** The phrase terminator. It is ";;" by default and ";" when you
@@ -167,6 +167,11 @@ val end_and_accept_current_phrase : LTerm_read_line.action
      ]}
  *)
 
+(** External editor command. [None] for default. *)
+val external_editor : string signal
+val set_external_editor : string -> unit
+val get_external_editor : unit -> string
+
 (** {6 History} *)
 
 val history : LTerm_history.t
@@ -195,6 +200,14 @@ val history_file_max_entries : int option ref
       default) the maximum number of entries if [history] will be
       used. *)
 
+val stashable_session_history : UTop_history.t
+  (** A history consisting of inputs and resulting values or errors of the
+      current session. Because stashing is supposed to produce a valid OCaml
+      file which will behave roughly the same as the console, it is best if
+      this history never gets truncated. While this will certainly lead to a
+      slight memory leaking problem, UTop sessions are rarely long enough to
+      make it a serious issue. *)
+
 (** {6 Console specific configuration} *)
 
 type profile = Dark | Light
@@ -223,7 +236,7 @@ val prompt : LTerm_text.t React.signal ref
 
 (** {6 Hooks} *)
 
-val new_command_hooks : (unit -> unit) Lwt_sequence.t
+val new_command_hooks : (unit -> unit) LTerm_dlist.t
   (** Functions called before each new command. *)
 
 val at_new_command : (unit -> unit) -> unit
@@ -315,11 +328,13 @@ val discard_formatters : Format.formatter list -> (unit -> 'a) -> 'a
 
 val split_words : string -> string list
 
-(** {6 compiler-libs reexports} *)
+ (** {6 compiler-libs reexports} *)
 
-val load_path : string list ref
-  (** [load_path] is an alias of [Config.load_path], normally hidden in toplevel.
-      It contains the list of directories added by findlib-required packages
+val get_load_path : unit -> string list
+val set_load_path : string list -> unit
+  (** [get_load_path] and [set_load_path] manage the include directories.
+
+      The internal variable contains the list of directories added by findlib-required packages
       and [#directory] directives. *)
 
 (**/**)
@@ -329,5 +344,5 @@ val load_path : string list ref
 val prompt_continue : LTerm_text.t React.signal ref
 val prompt_comment : LTerm_text.t React.signal ref
 val smart_accept : bool ref
-val new_prompt_hooks : (unit -> unit) Lwt_sequence.t
+val new_prompt_hooks : (unit -> unit) LTerm_dlist.t
 val at_new_prompt : (unit -> unit) -> unit
